==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/jdk/java/foreign/enablenativeaccess/panama_module/org/openjdk/foreigntest/PanamaMainDirect.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.openjdk.foreigntest;

import java.lang.foreign.*;

public class PanamaMainDirect {
    public static void main(String[] args) {
       testDirectAccessCLinker();
       testDirectAccessMemorySegment();
    }

    public static void testDirectAccessCLinker() {
        System.out.println("Trying to get Linker");
        Linker.nativeLinker();
        System.out.println("Got Linker");
   }

    public static void testDirectAccessMemorySegment() {
        System.out.println("Trying to get MemorySegment");
        MemorySegment.ofAddress(MemoryAddress.NULL, 4000, MemorySession.global());
        System.out.println("Got MemorySegment");
   }
}

==> openjdk-21_21~7ea.orig.tar.xz: openjdk-21-21~7ea/test/jdk/java/foreign/enablenativeaccess/panama_module/org/openjdk/foreigntest/PanamaMainDirect.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.openjdk.foreigntest;

import java.lang.foreign.*;
import java.lang.foreign.SegmentScope;

public class PanamaMainDirect {
    public static void main(String[] args) {
       testDirectAccessCLinker();
       testDirectAccessMemorySegment();
    }

    public static void testDirectAccessCLinker() {
        System.out.println("Trying to get Linker");
        Linker.nativeLinker();
        System.out.println("Got Linker");
   }

    public static void testDirectAccessMemorySegment() {
        System.out.println("Trying to get MemorySegment");
        MemorySegment.ofAddress(0, 4000, SegmentScope.global());
        System.out.println("Got MemorySegment");
   }
}
